@@ -60,6 +60,8 @@ lm.LMtests <- function(model, listw, zero.policy=FALSE, test="LMerr",
 		parameter <- vec[2]
 		names(parameter) <- "df"
 		p.value <- 1 - pchisq(statistic, parameter)
+		if (p.value < 0 || p.value > 1) 
+		    warning("Out-of-range p-value: reconsider test arguments")
 		names(p.value) <- ""
 		method <- "Lagrange multiplier diagnostics for spatial dependence"
 		data.name <- paste("\n", paste(strwrap(paste("model: ",
